# Generated by roxygen2: do not edit by hand

export(add_conservation_calcs)
export(add_humidity_adjustments)
export(add_humidity_calcs)
export(add_time_vars)
export(calcAD)
export(calcAH)
export(calcCoolingCapacity)
export(calcCoolingPower)
export(calcDP)
export(calcEMC_wood)
export(calcEnthalpy)
export(calcFP)
export(calcFtoC)
export(calcHR)
export(calcLM)
export(calcMR)
export(calcMould_VTT)
export(calcMould_Zeng)
export(calcPI)
export(calcPw)
export(calcPws)
export(calcRH_AH)
export(calcRH_DP)
export(calcSH)
export(calcSensibleHeatRatio)
export(calcSensibleHeating)
export(calcTemp)
export(calcTotalHeating)
export(data_file_path)
export(graph_TRH)
export(graph_TRHbivariate)
export(graph_psychrometric)
export(run_ConSciR_app)
export(shiny_dataUploadServer)
export(shiny_dataUploadUI)
export(tidy_Hanwell)
export(tidy_Meaco)
export(tidy_TRHdata)
import(openair)
import(shiny)
import(utils)
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,mutate)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,lims)
importFrom(ggplot2,scale_colour_viridis_c)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(lubridate,as_date)
importFrom(lubridate,day)
importFrom(lubridate,dmy_hm)
importFrom(lubridate,floor_date)
importFrom(lubridate,hour)
importFrom(lubridate,make_date)
importFrom(lubridate,month)
importFrom(lubridate,now)
importFrom(lubridate,parse_date_time)
importFrom(lubridate,wday)
importFrom(lubridate,year)
importFrom(padr,pad)
importFrom(readr,cols)
importFrom(readr,read_csv)
importFrom(readr,write_excel_csv)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(rlang,sym)
importFrom(shiny,runApp)
importFrom(stats,as.formula)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,uniroot)
importFrom(stringr,fixed)
importFrom(stringr,regex)
importFrom(stringr,str_detect)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_trim)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,separate)
importFrom(tools,file_ext)
